@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003--2008  Enrico Zini <enrico@enricozini.org>
+ * Copyright (C) 2003--2011  Enrico Zini <enrico@enricozini.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,30 +32,6 @@ using namespace wibble;
 
 namespace buffy
 {
-
-Directory::Directory(const std::string& name) : dir(0)
-{
-	if ((dir = opendir(name.c_str())) == NULL)
-		throw wibble::exception::File(name, "opening directory");
-}
-
-void stat(const std::string& name, struct stat* st)
-{
-	if (::stat(name.c_str(), st) != 0)
-			throw wibble::exception::File(name, "getting stat() informations");
-}
-
-bool statIfFound(const std::string& name, struct stat* st)
-{
-	if (::stat(name.c_str(), st) != 0)
-		if (errno == ENOENT)
-			return false;
-		else
-			throw wibble::exception::File(name, "getting stat() informations");
-	return true;
-}
-
-
 }
 
 // vim:set ts=4 sw=4:
